1.3.1
=====

Fix error on Python 2 due to old-style class resolution.

1.3
===

Moved hosting to Github.

Add support for linking timestamps from a git repository according to
version tags as found in the file.

Use setuptools_scm again.

1.1
===

Use hgtools due to setuptools_scm #21.

1.0
===

Initial release.
